StepsController class

Mixed-in types

Constructors

StepsController({int currentIndex = 0, bool isCompleted = false})

Properties

currentIndex ↔ int
指示当前进行态的步骤
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
isCompleted ↔ bool
整个流程是否完成
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
backStep() → void
向后一步
dispose() → void
Discards any resources used by the object.
inherited
forwardStep() → void
向前一步
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setCompleted() → void
整个链路完成
setCurrentIndex(int currentIndex) → void
设置当前步骤条的 index,从 0 开始。
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited